@@ -10,6 +10,7 @@ class Database():
         self.status_lock = threading.Lock()
         self.queries = queue.Queue()
         self.has_queries = threading.Semaphore(value=0)
+        self.query_ended=threading.Event()
         self.is_up = threading.Event()
         self.waiters = waiters
         self.executors = executors
@@ -19,9 +20,11 @@ class Database():
 
     def run_queries(self):
         while self.has_queries.acquire():
+            self.query_ended.clear()
             query = self.queries.get()
             self.waiters[query.wait].executor = self.executors[query.type]
             self.waiters[query.wait].run_query(query, self)
+            self.query_ended.set()
 
     def change_status(self, new_status):
         with self.status_lock:
