@@ -1,5 +1,5 @@
 import django
-import django.db
+import django.db.utils
 
 from .database import DatabaseStatus
 
